@@ -130,6 +130,34 @@ class color_detect(Camera):  #颜色检测
         self.pts = deque(maxlen=self.mybuffer)
         self.counter = 0
         
+    def set_hsv(self,image,color):
+        self.HSV = cv2.cvtColor(image, cv2.COLOR_BGR2HSV)
+        cv2.imshow("imageHSV", self.HSV)
+        cv2.imshow('image', image)
+        cv2.setMouseCallback("imageHSV", self.getpos)
+        cv2.waitKey(0)
+        self.color_list_lower=[self.Hmax, self.Smax, self.Vmax]
+        self.color_list_upper=[self.Hmin, self.Smin, self.Vmin]
+        self.colorLower = np.array(self.color_list_lower)  #这是红色的数值
+        self.colorUpper = np.array(self.color_list_upper)
+        self.color=color
+        
+    def getpos(self,event,x,y,flags,param):
+        if event==cv2.EVENT_LBUTTONDOWN: #定义一个鼠标左键按下去的事件
+            print(self.HSV[y, x])
+            if self.HSV[y, x][0]<self.Hmin:
+                self.Hmin=self.HSV[y, x][0]
+            if  self.HSV[y, x][0]>self.Hmax:
+                self.Hmax=self.HSV[y, x][0]
+            if  self.HSV[y, x][1]<self.Smin:
+                self.Smin=self.HSV[y, x][1]
+            if  self.HSV[y, x][1]>self.Smax:
+                self.Smax=self.HSV[y, x][1]
+            if  self.HSV[y, x][2]<self.Vmin:
+                self.Vmin=self.HSV[y, x][2]
+            if  self.HSV[y, x][2]>self.Vmax:
+                self.Vmax=self.HSV[y, x][2]
+        
     def setcolorvalue(self, color, color_list_low, color_list_up):
         self.color_list_lower=color_list_low
         self.color_list_upper=color_list_up
@@ -188,8 +216,8 @@ class color_detect(Camera):  #颜色检测
             center = (int(M["m10"]/M["m00"]), int(M["m01"]/M["m00"]))
         #只有当半径大于100mm时，才执行画图
             if radius > 5:
-                #img_circle=cv2.circle(self.frame, (int(x), int(y)), int(radius), (0, 255, 255), 2)
-                #cv2.circle(self.frame, center, 5, (0, 0, 255), -1)
+                # img_circle=cv2.circle(self.frame, (int(x), int(y)), int(radius), (0, 255, 255), 2)
+                # cv2.circle(self.frame, center, 5, (0, 0, 255), -1)
 
             #把质心添加到pts中，并且是添加到列表左侧
                 self.pts.appendleft(center)
@@ -206,7 +234,8 @@ class color_detect(Camera):  #颜色检测
 class erweima_recognize(Camera):  #二维码检测类
     def __init__(self):
         self.data='none'
-
+        
+        
     def recognize(self,img):
         self.data='none'
         # 读取当前帧
@@ -224,11 +253,25 @@ class erweima_recognize(Camera):  #二维码检测类
         # 提取条形码的边界框的位置
         # 画出图像中条形码的边界框
             (x, y, w, h) = barcode.rect
-            cv2.rectangle(image, (x, y), (x + w, y + h), (0, 0, 255), 2)
+            # nts = cv2.findContours(barcode, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)[-2]
+            # print('x, y, w,h', x, y, w, h)
+            cv2.rectangle(image, (x,y),(x+w,y+h),(0, 0, 255), 5)
+            cv2.circle(image, (int(x+w/2), int(y+h/2)), int( h/2), (255, 0, 0), 5)
+            
+            if x>0 and y >0:
+                img_new = image[y:y+h, x:x+w]
+                # cv2.imshow('img_new',img_new)
+                # cv2.waitKey(0)
+            else:
+                img_new = image
+            # cv2.imshow('img_new',img_new)
+            # cv2.waitKey(40)
+            # cv2.circle(image, (int(x+w/2), int(y+h/2)), int( h/2), (255, 0, 0), 5)
         # 条形码数据为字节对象，所以如果我们想在输出图像上
         # 画出来，就需要先将它转换成字符串
             barcodeData = barcode.data.decode("utf-8")
             self.data=barcodeData
+    
 
 class model_recognize(Camera):  #使用模型识别类,改一下item的名字就好
     #打开摄像头识别垃圾图片并返回对应文字
@@ -291,6 +334,27 @@ def take_photos(img,class_num_dir,name):
     if ret==1:
         print('图片成功保存到路径：',filename)
         return ret
+    
+
+def distortion(img):
+    mtx = []
+    dist = []
+
+    npzfile = np.load('calibrate.npz')
+    mtx = npzfile['mtx']
+    dist = npzfile['dist']
+    dist=dist[0:4]
+    h, w = img.shape[:2]
+    newcameramtx, roi = cv2.getOptimalNewCameraMatrix(mtx, dist, (w, h), 1, (w, h))
+    dst = cv2.undistort(img, mtx, dist, None, newcameramtx)
+
+    # crop the image
+    x, y, w, h = roi
+    if roi != (0, 0, 0, 0):
+        dst = dst[y:y + h, x:x + w]
+        dst = cv2.resize(dst, (320,320))
+    return dst
+
 
 
 # 检测类：人脸检测、颜色检测
@@ -317,26 +381,30 @@ while 1:
             cv2.imwrite(img_path,frame_new)
             img = Image.open(img_path)
             s.recognize(img)
+            print(s.pro)
             print(s.data)
 '''
 '''
-# #测试二维码识别
-# cam = cv2.VideoCapture(0)  #打开摄像头
-# #er=erweima_recognize()
-# while 1:
-#     ret,img=read_cam(cam)
-#     if ret==1:  #说明成功读取到了图片
-#         cv2.imshow("img",img)
-#         cv2.waitKey(1)
-#         #er.recognize(img)
-#         #print(er.data)
-
-# cam = cv2.VideoCapture(0)
-# while 1:
-#     img = read_cam(cam)
-#     cv2.imshow('img',img)
-#     cv2.waitKey(1)
-#     #cv2.destoryAllwindows()
+#测试二维码识别
+cam = cv2.VideoCapture(0)  #打开摄像头
+er=erweima_recognize()
+while 1:
+    ret,img=read_cam(cam)
+    if ret==1:  #说明成功读取到了图片
+        cv2.imshow("img",img)
+        cv2.waitKey(1)
+        er.recognize(img)
+        # er.detect(img)
+        # cv2.imshow('img', img_new)
+        # print(er.data)
+'''
+'''
+cam = cv2.VideoCapture(0)
+while 1:
+    ret, img = read_cam(cam)
+    cv2.imshow('img', img)
+    cv2.waitKey(1)
+    #cv2.destoryAllwindows()
 '''
 '''
 #测试颜色阈值
