@@ -15,7 +15,7 @@ audio_path = main_path+'speech/'#音频文件夹
 
 def test():
     print('hello lxy!')
-    
+
 def hello():
     print('you successful twice')
 
@@ -24,25 +24,25 @@ class Yuyin():
         self.app_id=self.TxtRead(txt_path+'APP_ID.txt')
         self.api_key=self.TxtRead(txt_path+'API_KEY.txt')
         self.secret_key=self.TxtRead(txt_path+'SECRET_KEY.txt')
-        
+
         self.client=AipSpeech(self.app_id,self.api_key,self.secret_key)
-    
+
     #读取文件并保存为字符串
     def TxtRead(self,filename):
-        f = open(filename,"r")   
+        f = open(filename,"r")
         txt=f.read()
-        f.close() 
+        f.close()
         return txt
-    
+
     #修改成语音文件格式到适合百度语音api
     def downsampleWav(self,src, dst, inrate=48000, outrate=16000, inchannels=1, outchannels=1):
         if not os.path.exists(src):
             print ('没有旧音频文件')
             return False
- 
+
         if not os.path.exists(os.path.dirname(dst)):
             os.makedirs(os.path.dirname(dst))
- 
+
         try:
             s_read = wave.open(src, 'rb')
             params = s_read.getparams()
@@ -52,10 +52,10 @@ class Yuyin():
         except:
             print ('打开旧音频文件失败')
             return False
- 
+
         n_frames = s_read.getnframes()
         data = s_read.readframes(n_frames)
- 
+
         try:
             converted = audioop.ratecv(data, 2, inchannels, inrate, outrate, None)
             if outchannels == 1 and inchannels != 1:
@@ -63,7 +63,7 @@ class Yuyin():
         except:
             print ('转换格式失败')
             return False
- 
+
         try:
             s_write.setparams((outchannels, 2, outrate, 0, 'NONE', 'Uncompressed'))
             s_write.writeframes(converted[0])
@@ -71,7 +71,7 @@ class Yuyin():
             print(e)
             print ('保存新音频失败')
             return False
- 
+
         try:
             s_read.close()
             s_write.close()
@@ -116,13 +116,13 @@ class Yuyin():
         wf.setframerate(RATE)
         wf.writeframes(b''.join(frames))
         wf.close()
-    
+
         file_new_name=audio_path+'new.wav'
         self.downsampleWav(file_name, file_new_name)
         os.remove(file_name)
         os.rename(file_new_name,file_name)
 
-    # 语音识别返回识别结果字符串   中文普通话识别的免费次数为50000次。            
+    # 语音识别返回识别结果字符串   中文普通话识别的免费次数为50000次。
     def stt(self,filename):  #识别.wav文件中的语音
         try:
             filename=audio_path+filename+'.wav'
@@ -149,17 +149,17 @@ class Yuyin():
             except:
                 print("没有连接网络")
                 return "没有连接网络"
-        
+
 
     #将文本转为音频  语音合成免费额度只有5000次（未认证），认证之后有50000次，在180天内有效
     def tts(self,txt,filename):
         if len(txt) != 0:
             word = txt
-        try:
+        #try:
             result  = self.client.synthesis(word,'zh',1, {
                 'vol': 5,'per':0,
             })
-            # 合成正确返回audio.mp3，错误则返回dict 
+            # 合成正确返回audio.mp3，错误则返回dict
             if not isinstance(result, dict):
                 with open(audio_path+filename+'.mp3', 'wb') as f:
                     f.write(result)
@@ -167,48 +167,49 @@ class Yuyin():
                 f.close()
             else :
                 print(txt+'文字转音频失败:'+txt)
-        except:
-            print('没有连接网络')
+#         except:
+#             print('没有连接网络')
 
-    def play_bufen(self,filename,play_time):    
+    def play_bufen(self,filename,play_time):
         pygame.mixer.init(frequency=16000,size=-16,channels=1,buffer=2000)
         track = pygame.mixer.music.load(audio_path+filename)
         pygame.mixer.music.play()
         time.sleep(play_time)
         pygame.mixer.music.stop()
-    
+
     # 播放音频及音乐
     def play_music(self,filename,model=0,flag=0,time=0):  #只能播放.mp3文件  model=1是播放音乐，=0是播放音频文件  flag=0是播放全部，=1是播放部分。 time是播放音乐多长时间。
-        try:
-            try:
-                pygame.mixer.init(frequency=16000,size=-16,channels=1,buffer=2000)
-                f=filename.split('.')
-                if f[1]=='wav':
-                    track = pygame.mixer.Sound(audio_path+filename)
-                    track.play()#循环次数loops，开始时间start
-                
-                elif f[1]=='mp3':
-                    if model == 0: #播放音频
-                        track = pygame.mixer.music.load(audio_path+filename)
-                        pygame.mixer.music.play()#循环次数loops，开始时间start
-                        
-                    elif model==1:   #播放音乐
-                        track = pygame.mixer.music.load(audio_path+filename)
-                        if flag==0:  #播放全部
-                            pygame.mixer.music.play()#循环次数loops，开始时间start
-                            while (pygame.mixer.music.get_busy()):  #等待播放完毕
-                                if pygame.mixer.music.get_busy()==0:
-                                    break;
-                                
-                        else:  #播放部分
-                            self.play_bufen(filename,time)
-                
-            except:
-                print('没有这个音频文件:'+filename)
-        except:
-            print('没有打开音响')
+#         try:
+#             try:
+        pygame.mixer.init(frequency=16000,size=-16,channels=1,buffer=2000)
+        f=filename.split('.')
+        if f[1]=='wav':
+            track = pygame.mixer.Sound(audio_path+filename)
+            track.play()#循环次数loops，开始时间start
+
+        elif f[1]=='mp3':
+            if model == 0: #播放音频
+                track = pygame.mixer.music.load(audio_path+filename)
+                pygame.mixer.music.play()#循环次数loops，开始时间start
+
+            elif model==1:   #播放音乐
+                track = pygame.mixer.music.load(audio_path+filename)
+                if flag==0:  #播放全部
+                    pygame.mixer.music.play()#循环次数loops，开始时间start
+                    while (pygame.mixer.music.get_busy()):  #等待播放完毕
+                        if pygame.mixer.music.get_busy()==0:
+                            break;
+
+                else:  #播放部分
+                    self.play_bufen(filename,time)
+
+#             except:
+#                 print('没有这个音频文件:'+filename)
+#         except:
+#             print('没有打开音响')
+
+#测试录音+语音识别
 '''
-#测试录音+语音识别       
 s=Yuyin()
 s.my_record(3,"1")
 txt=s.stt("1")
@@ -217,6 +218,6 @@ print(txt)
 '''
 #测试文本转语音
 s=Yuyin()
-s.tts('你好',"2")  #tts保存为mp3格式
-s.play_music('2.mp3')
+s.tts('辛苦了',"c3")  #tts保存为mp3格式
+s.play_music("c3.mp3")
 '''
\ No newline at end of file
